@@ -13,9 +13,6 @@ class AdbExt(object):
         self.is_helper_ready = False
         self.width, self.height = self.get_device_size()
         self.dir_path = os.path.dirname(os.path.abspath(__file__))  # 当前文件所在的目录绝对路径
-        self.temp_name = 'temp_{}'.format(self.util.sn)  # 临时文件名加上sn，防止多个手机多线程是有冲突
-        self.temp_name = self.temp_name.replace('.', '').replace(':', '')  # 远程机器sn特殊，处理一下。如：10.15.34.56:11361
-        self.temp_pc_dir_path = tempfile.gettempdir()
         self.temp_device_dir_path = '/data/local/tmp'
 
     def get_device_size(self):
@@ -66,9 +63,6 @@ class AdbExt(object):
         arg = 'app_process -Djava.class.path=/data/local/tmp/adbui /data/local/tmp com.ysbing.yadb.Main -{}'.format(cmd)
         return self.util.shell(arg)
 
-    def get_pc_temp_name(self):
-        return os.path.join(self.temp_pc_dir_path, self.temp_name)
-
     def delete_from_device(self, path):
         self.util.shell('rm -rf {}'.format(path))
 
